@@ -1,4 +1,3 @@
-context("Recording db interactions")
 # This should be run first so that the .dittodb_env environment is clean.
 
 test_that("We can capture db interactions", {
@@ -7,7 +6,7 @@ test_that("We can capture db interactions", {
   expect_null(.dittodb_env$db_path)
 
   start_db_capturing()
-  con <- nycflights13_create_sqlite()
+  suppressMessages(con <- nycflights13_create_sqlite(verbose = FALSE))
 
   # our state has been updated
   expect_identical(.dittodb_env$db_path, file.path(temp_dir, "_memory_"))
@@ -36,7 +35,7 @@ test_that("We can capture db interactions", {
 test_that("We can specify the path when starting capture", {
   new_path <- file.path(temp_dir, "start_capture_path")
   start_db_capturing(new_path)
-  con <- nycflights13_create_sqlite()
+  suppressMessages(con <- nycflights13_create_sqlite())
 
   # our state has been updated
   expect_identical(.dittodb_env$db_path, file.path(new_path, "_memory_"))
